@@ -1,16 +1,24 @@
+import os
+import pathlib
+import re
+import sys
+
+
+content = (pathlib.Path(__file__).parent.parent / 'feedparser/__init__.py').read_text()
+match = re.search(r"""__version__ = ['"](?P<version>.+?['"])""", content)
+version = match.group('version')
+release = version
+
 # project information
-project = u'feedparser'
-copyright = u'2004-2008 Mark Pilgrim, 2010-2012 Kurt McKee'
-version = u'5.1.3'
-release = u'5.1.3'
-language = u'en'
+project = 'feedparser'
+copyright = '2010-2020 Kurt McKee, 2004-2008 Mark Pilgrim'
+language = 'en'
 
 # documentation options
 master_doc = 'index'
 exclude_patterns = ['_build']
 
 # use a custom extension to make Sphinx add a <link> to feedparser.css
-import sys, os.path
 sys.path.append(os.path.dirname(os.path.abspath(__file__)))
 extensions = ['add_custom_css']
 
